@@ -48,7 +48,7 @@ def check_file(file_name, extension):
     return
 
 
-def generate_input_func(user_args, hpc_args):
+def generate_input_func(user_args):
     """
     Wrapper function for CLI gen_input call
 
@@ -161,8 +161,8 @@ def gen_job_func(user_args, unknown_args):
 
     """
 
+    # Get current machine name
     hpc_args = hpc.read_args(['generate_job'] + unknown_args)
-
     if hpc_args.profile == 'read_hostname':
         machine = parse_hostname()
     else:
@@ -174,7 +174,7 @@ def gen_job_func(user_args, unknown_args):
     ]
 
     if machine not in supported_machines:
-        sys.exit("Error: Unsupported machine")
+        sys.exit("Error: Unsupported machine, perhaps try --profile")
 
     default_mod = {
         "csf3": "apps/binapps/gaussian/g16c01_em64t",
@@ -202,17 +202,23 @@ def gen_job_func(user_args, unknown_args):
         "csf4": 4
     }
 
+    if hpc_args.node_type == "high_mem":
+        mem_multiplier = {
+            "csf3": 16,
+            "csf4": 16
+        }
+
     # Create submission script
     gen_job.create_submission_script(
         "{}.DATA".format(user_args.com_file_name[:-4]),
         user_args.n_cores,
         user_args.n_cores * mem_multiplier[machine],
-        machine,
         default_mod[machine],
         default_scratch[machine],
         default_chk[machine],
         default_version[machine],
         gen_fchk=not user_args.no_gen_fchk,
+        hpc_extra=unknown_args
     )
 
     return
@@ -448,7 +454,7 @@ def cd_extractor_func(user_args):
         np.savetxt(
             out_name,
             out_array,
-            header="Charges (e), dipole_x (A e), dipole_y (A e), dipole_z (A e)",
+            header="Charges (e), dipole_x (A e), dipole_y (A e), dipole_z (A e)", # noqa
             fmt="% 7.5e"
         )
 
@@ -692,12 +698,6 @@ def read_args(arg_list=None):
         help="Number of cores (threads) to request"
     )
 
-    gen_job.add_argument(
-        "--short",
-        action="store_true",
-        help="Request short queue (1 hour and 12 cores max)"
-    )
-
     gen_job.add_argument(
         "--no_gen_fchk",
         action="store_true",
@@ -894,7 +894,7 @@ def read_args(arg_list=None):
     _args, _ = parser.parse_known_args(arg_list)
 
     # select parsing option based on sub-parser
-    if _args.prog in ['extractor', 'gen_job', 'gen_input']:
+    if _args.prog in ['extractor', 'gen_job']:
         args, hpc_args = parser.parse_known_args(arg_list)
         args.func(args, hpc_args)
     else:
